link.riak
=========

**link.riak** provides a key/value store driver for Riak.

See documentation_ for more informations.

.. _documentation: https://linkriak.readthedocs.io

.. image:: https://img.shields.io/pypi/l/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: License

.. image:: https://img.shields.io/pypi/status/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: Development Status

.. image:: https://img.shields.io/pypi/v/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/implementation/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/wheel/link.riak.svg?style=flat-square
   :target: https://travis-ci.org/linkdd/link.riak
   :alt: Download format

.. image:: https://travis-ci.org/linkdd/link.riak.svg?branch=master&style=flat-square
   :target: https://travis-ci.org/linkdd/link.riak
   :alt: Build status

.. image:: https://coveralls.io/repos/github/linkdd/link.riak/badge.svg?style=flat-square
   :target: https://coveralls.io/r/linkdd/link.riak
   :alt: Code test coverage

.. image:: https://img.shields.io/pypi/dm/link.riak.svg?style=flat-square
   :target: https://pypi.python.org/pypi/link.riak/
   :alt: Downloads

.. image:: https://landscape.io/github/linkdd/link.riak/master/landscape.svg?style=flat-square
   :target: https://landscape.io/github/linkdd/link.riak/master
   :alt: Code Health

.. image:: https://www.quantifiedcode.com/api/v1/project/182155bb82f744f79d998d300e49f6df/badge.svg
  :target: https://www.quantifiedcode.com/app/project/182155bb82f744f79d998d300e49f6df
  :alt: Code issues

Installation
------------

.. code-block:: text

   pip install link.riak
